@@ -36,7 +36,7 @@ try:
 except ImportError:
     has_ooolib = False
 
-from django.utils.translation import ugettext as _
+from django.utils.translation import gettext as _
 
 class UnsupportedFileFormat(Exception):
     pass
